@@ -21,6 +21,13 @@ from mlcvzoo_base.configuration.reduction_mapping_config import (
 logger = logging.getLogger(__name__)
 
 
+class DuplicateOutputClassError(Exception):
+    """
+    Error that indicates that an output class ID or output class name of
+    an reduction mapping is not unique / has duplicates.
+    """
+
+
 class AnnotationClassMapper:
     """
     Class for handling the mapping of class ids to class names during the parsing of annotation
@@ -37,7 +44,6 @@ class AnnotationClassMapper:
         class_mapping: ClassMappingConfig,
         reduction_mapping: Optional[ReductionMappingConfig] = None,
     ) -> None:
-
         self.class_mapping_config: ClassMappingConfig = class_mapping
 
         # Dictionary that defines how a class ID during the parsing of annotation files
@@ -505,7 +511,6 @@ class AnnotationClassMapper:
         annotation_class_name_to_model_class_id_map: Dict[str, int],
         reduction_mapping_config: Optional[ReductionMappingConfig],
     ) -> Dict[int, List[ClassIdentifier]]:
-
         default_model_class_id_to_class_identifier_map: Dict[int, List[ClassIdentifier]] = {}
         model_class_id_to_class_identifier_map: Dict[int, List[ClassIdentifier]] = {}
 
@@ -523,7 +528,7 @@ class AnnotationClassMapper:
         if reduction_mapping_config is not None:
             for index, mapping_entry in enumerate(reduction_mapping_config.mapping):
                 if mapping_entry.output_class_id in output_class_id_map:
-                    raise ValueError(
+                    raise DuplicateOutputClassError(
                         "Duplicate definition for output-class-id='%s' "
                         "for mapping_entry at index='%s':\n"
                         " - already stored mapping-entry='%s'\n"
@@ -537,7 +542,7 @@ class AnnotationClassMapper:
                     )
 
                 if mapping_entry.output_class_name in output_class_name_map:
-                    raise ValueError(
+                    raise DuplicateOutputClassError(
                         "Duplicate definition for output-class-name='%s' "
                         "for mapping_entry at index='%s':\n"
                         " - already stored mapping-entry='%s'\n"
@@ -586,7 +591,6 @@ class AnnotationClassMapper:
         mapping_entry: ReductionMappingMappingConfig,
         index: int,
     ) -> Dict[int, List[ClassIdentifier]]:
-
         assert mapping_entry.model_class_ids is not None
 
         error_class_ids: List[int] = []
@@ -629,12 +633,10 @@ class AnnotationClassMapper:
         mapping_entry: ReductionMappingMappingConfig,
         index: int,
     ) -> Dict[int, List[ClassIdentifier]]:
-
         assert mapping_entry.model_class_names is not None
 
         error_class_names: List[str] = []
         for model_class_name in mapping_entry.model_class_names:
-
             if model_class_name in annotation_class_name_to_model_class_id_map:
                 model_class_id = annotation_class_name_to_model_class_id_map[model_class_name]
             else:
@@ -672,7 +674,6 @@ class AnnotationClassMapper:
         annotation_class_id_to_model_class_name_map: Dict[int, str],
         model_class_id_to_class_identifier_map: Dict[int, List[ClassIdentifier]],
     ) -> Dict[str, List[ClassIdentifier]]:
-
         return {
             annotation_class_id_to_model_class_name_map[model_class_id]: class_identifier
             for model_class_id, class_identifier in model_class_id_to_class_identifier_map.items()
