@@ -7,9 +7,10 @@
 
 from __future__ import annotations
 
+from typing import Any, Dict
+
 
 class ClassIdentifier:
-
     __delimiter: str = "_"
 
     def __init__(
@@ -32,6 +33,12 @@ class ClassIdentifier:
     def __repr__(self) -> str:
         return f"{self.class_id}{ClassIdentifier.__delimiter}{self.class_name}"
 
+    def to_dict(self) -> Dict[str, Any]:
+        return {"class_id": self.class_id, "class_name": self.class_name}
+
+    def to_json(self) -> Any:
+        return self.to_dict()
+
     @property
     def class_id(self) -> int:
         return self.__class_id
