@@ -54,7 +54,6 @@ class OCRPerception(Perception):
             self.word_scores = [self.score]
 
     def __repr__(self) -> str:
-
         return f"OCRPerception({self.words} - {self.word_scores})"
 
     def __lt__(self, other: OCRPerception) -> bool:
@@ -81,6 +80,9 @@ class OCRPerception(Perception):
 
         return perception
 
+    def to_json(self) -> Any:
+        return self.to_dict()
+
     def clean(self, separator: str = " ") -> str:
         """
         Create a clean concatenated string that is build by the
