@@ -7,7 +7,7 @@
 from __future__ import annotations
 
 import math
-from typing import Any, List, Optional, Tuple, Type
+from typing import Any, Dict, List, Optional, Tuple, Type
 
 import cv2
 import numpy as np
@@ -115,6 +115,78 @@ class Segmentation(AnnotationAttributes, Classification):
             f"content='{self.content}')"
         )
 
+    def to_dict(self, raw_type: bool = False, reduced: bool = False) -> Dict[str, Any]:
+        if self.box:
+            _box = self.box if raw_type else self.box.to_dict()
+        else:
+            _box = None
+
+        if reduced:
+            return {
+                "box": _box,
+                "polygon": self.polygon,
+                "class_id": self.class_id,
+                "class_name": self.class_name,
+                "model_class_id": self.model_class_identifier.class_id,
+                "model_class_name": self.model_class_identifier.class_name,
+                "score": self.score,
+            }
+        else:
+            return {
+                "box": _box,
+                "polygon": self.polygon,
+                "class_identifier": self.class_identifier
+                if raw_type
+                else self.class_identifier.to_dict(),
+                "model_class_identifier": self.model_class_identifier
+                if raw_type
+                else self.model_class_identifier.to_dict(),
+                "score": self.score,
+                "difficult": self.difficult,
+                "occluded": self.occluded,
+                "content": self.content,
+            }
+
+    @staticmethod
+    def from_dict(input_dict: Dict[str, Any], reduced: bool = False) -> Segmentation:
+        # fmt: off
+        if reduced:
+            return Segmentation(**{
+                "box": Box(**input_dict["box"]),
+                "polygon": input_dict["polygon"],
+                "class_identifier": ClassIdentifier(**{
+                    "class_id": input_dict["class_id"],
+                    "class_name": input_dict["class_name"],
+                }),
+                "model_class_identifier": ClassIdentifier(**{
+                    "class_id": input_dict["model_class_id"],
+                    "class_name": input_dict["model_class_name"],
+                }),
+                "score": input_dict["score"],
+                "difficult": False,
+                "occluded": False,
+                "content": "",
+            })
+        else:
+            return Segmentation(**{
+                "box": Box(**input_dict["box"]),
+                "polygon": input_dict["polygon"],
+                "class_identifier": ClassIdentifier(
+                    **input_dict["class_identifier"]
+                ),
+                "model_class_identifier": ClassIdentifier(
+                    **input_dict["model_class_identifier"]
+                ),
+                "score": input_dict["score"],
+                "difficult": input_dict["difficult"],
+                "occluded": input_dict["occluded"],
+                "content": input_dict["content"],
+            })
+        # fmt: on
+
+    def to_json(self) -> Any:
+        return self.to_dict(raw_type=False)
+
     def to_bounding_box(self, image_shape: Optional[Tuple[int, int]] = None) -> BoundingBox:
         """
         Manually build the bounding box object which covers the rectangular area
@@ -230,7 +302,7 @@ class Segmentation(AnnotationAttributes, Classification):
 
         min_area_rect = cv2.minAreaRect(np_polygon.astype(int))
         box = order_points(polygon=cv2.boxPoints(min_area_rect), sort_by_euclidean=False)
-        return np.int0(box).astype(np.float32)  # type: ignore[return-value]
+        return np.intp(box).astype(np.float32)  # type: ignore[return-value]
 
     def copy_segmentation(self, class_identifier: ClassIdentifier) -> Segmentation:
         return Segmentation(
