@@ -7,15 +7,9 @@
 Module for enumerating options of annotation and file formats, as well as data subsets and
 respective phases. Furthermore mlflow configuration options can be found here.
 """
-from enum import auto
+from enum import Enum
 from typing import Any, List
 
-try:
-    # python3.10
-    from enum import StrEnum  # type: ignore
-except ImportError:
-    from backports.strenum import StrEnum
-
 
 class BaseType:
     """Class for accessing internal attributes"""
@@ -150,7 +144,7 @@ class MLFLowTrackingUriTypes(BaseType):
     POSTGRES = "postgresql"
 
 
-class OpenCVImageFormats(StrEnum):
+class OpenCVImageFormats(Enum):
     BMP = ".bmp"
     PBM = ".pbm"
     PGM = ".pgm"
@@ -163,5 +157,5 @@ class OpenCVImageFormats(StrEnum):
     PNG = ".png"
 
 
-class DeviceQueryTypes(StrEnum):
-    NVIDIA_SMI = auto()
+class DeviceQueryTypes(Enum):
+    NVIDIA_SMI = "nvidia_smi"
