@@ -55,7 +55,7 @@ def evaluate_with_model(
         predicted_bounding_boxes_list.append(predicted_bounding_boxes)
 
     return MetricsComputation(
-        model_specifier=model.get_name(),
+        model_specifier=model.unique_name,
         classes_id_dict=None,
         iou_thresholds=iou_thresholds,
         gt_annotations=gt_annotations,
