@@ -7,23 +7,29 @@
 Module for configuring the parsing of information from yaml in python
 accessible attributes for the ReadFromFileModel class
 """
-from typing import Dict, List, Optional
+from typing import Optional
 
 import related
-from config_builder import BaseConfigClass
+from attr import define
 
-from mlcvzoo_base.api.configuration import Configuration
+from mlcvzoo_base.api.configuration import ModelConfiguration
 from mlcvzoo_base.configuration.annotation_handler_config import AnnotationHandlerConfig
 from mlcvzoo_base.configuration.class_mapping_config import ClassMappingConfig
-from mlcvzoo_base.configuration.detector_configs import DetectorConfig
 from mlcvzoo_base.configuration.reduction_mapping_config import ReductionMappingConfig
 
 
-@related.mutable(strict=True)
-class ReadFromFileConfig(BaseConfigClass, Configuration):
-    """Class for parsing information from yaml in respective hierarchy"""
+@define
+class ReadFromFileConfig(ModelConfiguration):
+    """
+    Class for parsing information from yaml in respective hierarchy
 
-    mutual_attribute_map: Dict[str, List[str]] = dict()
+    Attributes:
+        class_mapping (ClassMappingConfig):
+        annotation_handler_config:
+        use_image_name_hash:
+        include_segmentations:
+        reduction_class_mapping:
+    """
 
     class_mapping: ClassMappingConfig = related.ChildField(ClassMappingConfig)
 
@@ -38,5 +44,3 @@ class ReadFromFileConfig(BaseConfigClass, Configuration):
     reduction_class_mapping: Optional[ReductionMappingConfig] = related.ChildField(
         cls=ReductionMappingConfig, required=False, default=None
     )
-
-    base_config: DetectorConfig = related.ChildField(cls=DetectorConfig, default=DetectorConfig())
