@@ -72,7 +72,6 @@ class ReadFromFileModel(
         configuration: Optional[ReadFromFileConfig] = None,
         string_replacement_map: Optional[Dict[str, str]] = None,
     ):
-
         self.configuration: ReadFromFileConfig = ReadFromFileModel.create_configuration(
             from_yaml=from_yaml,
             configuration=configuration,
@@ -80,7 +79,6 @@ class ReadFromFileModel(
         )
         Model.__init__(
             self,
-            unique_name=self.configuration.base_config.MODEL_SPECIFIER,
             configuration=self.configuration,
             init_for_inference=True,
         )
@@ -160,7 +158,6 @@ class ReadFromFileModel(
         annotations_dict: Dict[str, BaseAnnotation] = {}
 
         for annotation in annotations:
-
             if annotation.image_path in annotations_dict:
                 logger.warning(
                     "Duplicate annotation data for image '%s'.\n"
@@ -197,7 +194,6 @@ class ReadFromFileClassificationModel(
         )
         ClassificationModel.__init__(
             self,
-            unique_name=self.get_name(),
             configuration=self.configuration,
             mapper=self.mapper,
             init_for_inference=True,
@@ -237,7 +233,6 @@ class ReadFromFileObjectDetectionModel(
         )
         ObjectDetectionModel.__init__(
             self,
-            unique_name=self.get_name(),
             configuration=self.configuration,
             mapper=self.mapper,
             init_for_inference=True,
@@ -246,7 +241,6 @@ class ReadFromFileObjectDetectionModel(
     def predict(
         self, data_item: Union[str, ImageType]
     ) -> Tuple[Union[str, ImageType], List[BoundingBox]]:
-
         include_segmentations: bool = self.configuration.include_segmentations
 
         if isinstance(data_item, str):
@@ -282,7 +276,6 @@ class ReadFromFileSegmentationModel(
         )
         SegmentationModel.__init__(
             self,
-            unique_name=self.get_name(),
             configuration=self.configuration,
             mapper=self.mapper,
             init_for_inference=True,
@@ -291,7 +284,6 @@ class ReadFromFileSegmentationModel(
     def predict(
         self, data_item: Union[str, ImageType]
     ) -> Tuple[Union[str, ImageType], List[Segmentation]]:
-
         if isinstance(data_item, str):
             data_hash = data_item
         else:
